==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_URL","URL");
define("_PRINTER","  ");
define("_FRIEND","  ");
define("_YOURNAME"," ");
define("_OK","Ok!");
define("_RELATED"," ");
define("_MOREABOUT"," ");
define("_NEWSBY"," ");
define("_MOSTREAD","  :");
define("_READMORE","...");
define("_BYTESMORE"," ");
define("_COMMENTSQ","?");
define("_COMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","");
define("_NOCOMMENTS"," ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD","");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","");
define("_COMMENTSWARNING","   ");
define("_SCORE",":");
define("_USERINFO","  ");
define("_READREST","  ...");
define("_REPLY","  ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT"," ");
define("_NOANONCOMMENTS","     ,  <a href=\"user.php\"></a>");
define("_PARENT","");
define("_ROOT","");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML :");
define("_POSTANON"," ");
define("_EXTRANS","   ");
define("_HTMLFORMATED","HTML ");
define("_PLAINTEXT"," ");
define("_ONN","...");
define("_SUBJECT","");
define("_COMMENTREPLY"," ");
define("_COMREPLYPRE"," ");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_SENDAMSG"," ");
define("_YOUSENDSTORY"," ");
define("_TOAFRIEND"," :");
define("_FYOURNAME"," :");
define("_FYOUREMAIL"," E-mail:");
define("_FFRIENDNAME","  :");
define("_FFRIENDEMAIL","E-mail  :");
define("_INTERESTING","Interesting Article at");
define("_HELLO","!");
define("_YOURFRIEND"," ");
define("_CONSIDERED","        .");
define("_FDATE",":");
define("_FTOPIC",":");
define("_YOUCANREAD","     ");
define("_FSTORY","");
define("_HASSENT"," ");
define("_THANKS","!");
define("_RECOMMEND","   ");
define("_PDATE",":");
define("_PTOPIC",":");
define("_COMESFROM","  ");
define("_THEURL","  :");
define("_PREVIEW","");
define("_NEWUSER"," ");
define("_OPTIONS","");
define("_REFRESH","");
define("_ADD","");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_URL","URL");
define("_PRINTER","  ");
define("_FRIEND","  ");
define("_YOURNAME"," ");
define("_OK","Ok!");
define("_RELATED"," ");
define("_MOREABOUT"," ");
define("_NEWSBY"," ");
define("_MOSTREAD","  :");
define("_READMORE","...");
define("_BYTESMORE"," ");
define("_COMMENTSQ","?");
define("_COMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","");
define("_NOCOMMENTS"," ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD","");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","");
define("_COMMENTSWARNING","   ");
define("_SCORE",":");
define("_USERINFO","  ");
define("_READREST","  ...");
define("_REPLY","  ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT"," ");
define("_NOANONCOMMENTS","     ,  <a href=\"user.php\"></a>");
define("_PARENT","");
define("_ROOT","");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML :");
define("_POSTANON"," ");
define("_EXTRANS","   ");
define("_HTMLFORMATED","HTML ");
define("_PLAINTEXT"," ");
define("_ONN","...");
define("_SUBJECT","");
define("_COMMENTREPLY"," ");
define("_COMREPLYPRE"," ");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_SENDAMSG"," ");
define("_YOUSENDSTORY"," ");
define("_TOAFRIEND"," :");
define("_FYOURNAME"," :");
define("_FYOUREMAIL"," E-mail:");
define("_FFRIENDNAME","  :");
define("_FFRIENDEMAIL","E-mail  :");
define("_INTERESTING","Interesting Article at");
define("_HELLO","!");
define("_YOURFRIEND"," ");
define("_CONSIDERED","        .");
define("_FDATE",":");
define("_FTOPIC",":");
define("_YOUCANREAD","     ");
define("_FSTORY","");
define("_HASSENT"," ");
define("_THANKS","!");
define("_RECOMMEND","   ");
define("_PDATE",":");
define("_PTOPIC",":");
define("_COMESFROM","  ");
define("_THEURL","  :");
define("_PREVIEW","");
define("_NEWUSER"," ");
define("_OPTIONS","");
define("_REFRESH","");
define("_ADD","");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
